<?php

/**
 * Responsible for setting up the plugin
 *
 * @since 1.0
 */
final class GBElementorLoader {
	/**
	 * Sets up the plugins_loaded action to load the plugin.
	 *
	 * @since 1.0
	 * @return void
	 */ 
	static public function init()
	{
		self::define_constants();
		
		register_activation_hook( GBE_FILE, __CLASS__ . '::gbe_activate' );
		
		add_action( 'admin_init', 			__CLASS__ . '::gbe_plugin_deactivate' );
		add_action( 'switch_theme', 		__CLASS__ . '::gbe_plugin_deactivate' );	
		add_action( 'plugins_loaded',       __CLASS__ . '::gbe_load' );
	}

	/**
	 * Define constants.
	 *
	 * @since 1.0
	 * @access private
	 * @return void
	 */ 
	static private function define_constants()
	{
		define( 'GBE_VERSION', '1.2' );
		define( 'GBE_FILE', trailingslashit( dirname( dirname( __FILE__ ) ) ) . 'gb-elementor.php' );
		define( 'GBE_DIR', plugin_dir_path( GBE_FILE ) );
		define( 'GBE_URL', plugins_url( '/', GBE_FILE ) );
	}

	/**
	 * Activate Widget Areas plugin
	 *
	 * @since 1.0
	 * @return void
	 */ 
	static public function gbe_activate()
	{
		if ( ! function_exists( 'gbeaver_create_cmb' ) || ! defined( 'ELEMENTOR_VERSION' ) )
		{
			//* Deactivate ourself
			deactivate_plugins( GBE_FILE );
			add_action( 'admin_notices', __CLASS__ . '::gbe_admin_notice_message' );
			return;	
		}
	}

	/**
	 * This function is triggered when the WordPress theme is changed.
	 * It checks if the GBeaver theme is active. If not, it deactivates itself.
	 *
	 * @since 1.0
	 */
	static public function gbe_plugin_deactivate()
	{
		if ( ! function_exists( 'gbeaver_create_cmb' ) || ! defined( 'ELEMENTOR_VERSION' ) )
		{
			//* Deactivate ourself
			deactivate_plugins( GBE_FILE );
			add_action( 'admin_notices', __CLASS__ . '::gbe_admin_notice_message' );
		}
	}

	/**
	 * Shows an admin notice if you're not using the Genesis Framework and Beaver Builder Plugin.
	 *
	 * @since 1.0
	 */
	static public function gbe_admin_notice_message()
	{
		if ( ! is_admin() ) {
			return;
		}
		else if ( ! is_user_logged_in() ) {
			return;
		}
		else if ( ! current_user_can( 'update_core' ) ) {
			return;
		}

		$error = sprintf( __( 'Sorry, you can\'t use the GBeaver Connect Elementor Plugin unless the <a href="%s">GBEAVER THEME</a> and <a href="%s">Elementor Plugin</a> is active. The plugin has been deactivated.', 'gb-elementor' ), 
			'http://gbeaver.com',
			'https://elementor.com' 
		);

		echo '<div class="error"><p>' . $error . '</p></div>';

		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}
	}

	/**
	 * Loads plugin.
	 *
	 * @since 1.0
	 * @return void
	 */ 
	static public function gbe_load()
	{

		//* Load textdomain for translation 
		load_plugin_textdomain( 'gb-elementor', false, GBE_DIR. '/languages' );
		
		self::gbe_load_files();
	}

	/**
	 * Loads classes and includes.
	 *
	 * @since 1.0
	 * @access private
	 * @return void
	 */ 
	static private function gbe_load_files()
	{
		// Classes
		require_once GBE_DIR . 'classes/class-gb-elementor.php';

		if( is_admin() )
		{
			require_once GBE_DIR . 'classes/class-plugin-updater.php';
			new GBEPluginUpdater( 'http://pwdtechnology.com/update-api/', GBE_VERSION );
		}
	}
}

GBElementorLoader::init();